@@ -25,6 +25,8 @@
 #  include "config.h"
 #endif
 
+#include "../gst-i18n-lib.h"
+
 #include <gst/gst.h>
 #include <errno.h>
 #include "gstfilesink.h"
@@ -33,6 +35,7 @@
 #include <sys/types.h>
 #include <unistd.h>
 
+
 GST_DEBUG_CATEGORY_STATIC (gst_filesink_debug);
 #define GST_CAT_DEFAULT gst_filesink_debug
 
@@ -56,19 +59,28 @@ enum {
   ARG_LOCATION
 };
 
-GST_PAD_QUERY_TYPE_FUNCTION (gst_filesink_get_query_types,
-  GST_QUERY_TOTAL,
-  GST_QUERY_POSITION
-)
+static const GstFormat *
+gst_filesink_get_formats (GstPad *pad)
+{
+  static const GstFormat formats[] = {
+    GST_FORMAT_BYTES,
+    0,
+  };
+  return formats;
+}
 
-GST_PAD_FORMATS_FUNCTION (gst_filesink_get_formats,
-  GST_FORMAT_BYTES
-)
+static const GstQueryType *
+gst_filesink_get_query_types (GstPad *pad)
+{
+  static const GstQueryType types[] = {
+    GST_QUERY_TOTAL,
+    GST_QUERY_POSITION,
+    0
+  };
+  return types;
+}
 
-
-static void	gst_filesink_base_init		(gpointer g_class);
-static void	gst_filesink_class_init		(GstFileSinkClass *klass);
-static void	gst_filesink_init		(GstFileSink *filesink);
+static void	gst_filesink_dispose		(GObject *object);
 
 static void	gst_filesink_set_property	(GObject *object, guint prop_id, 
 						 const GValue *value, GParamSpec *pspec);
@@ -83,35 +95,27 @@ static gboolean	gst_filesink_pad_query		(GstPad *pad, GstQueryType type,
 						 GstFormat *format, gint64 *value);
 static void	gst_filesink_chain		(GstPad *pad,GstData *_data);
 
+static void	gst_filesink_uri_handler_init	(gpointer g_iface, gpointer iface_data);
+  
 static GstElementStateReturn gst_filesink_change_state (GstElement *element);
 
-static GstElementClass *parent_class = NULL;
 static guint gst_filesink_signals[LAST_SIGNAL] = { 0 };
 
-GType
-gst_filesink_get_type (void) 
+static void
+_do_init (GType filesink_type)
 {
-  static GType filesink_type = 0;
-
-  if (!filesink_type) {
-    static const GTypeInfo filesink_info = {
-      sizeof(GstFileSinkClass),
-      gst_filesink_base_init,
-      NULL,
-      (GClassInitFunc)gst_filesink_class_init,
-      NULL,
-      NULL,
-      sizeof(GstFileSink),
-      0,
-      (GInstanceInitFunc)gst_filesink_init,
-    };
-    filesink_type = g_type_register_static (GST_TYPE_ELEMENT, "GstFileSink", &filesink_info, 0);
-  
-    GST_DEBUG_CATEGORY_INIT (gst_filesink_debug, "filesink", 0, "filesink element");
-  }
-  return filesink_type;
+  static const GInterfaceInfo urihandler_info = {
+    gst_filesink_uri_handler_init,
+    NULL,
+    NULL
+  };
+  g_type_add_interface_static (filesink_type, GST_TYPE_URI_HANDLER, &urihandler_info);
+  GST_DEBUG_CATEGORY_INIT (gst_filesink_debug, "filesink", 0, "filesink element");
 }
 
+GST_BOILERPLATE_FULL (GstFileSink, gst_filesink, GstElement, GST_TYPE_ELEMENT, _do_init);
+    
+
 static void
 gst_filesink_base_init (gpointer g_class)
 {
@@ -125,7 +129,6 @@ gst_filesink_class_init (GstFileSinkClass *klass)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
-  parent_class = g_type_class_peek_parent (klass);
 
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_LOCATION,
     g_param_spec_string ("location", "File Location", "Location of the file to write",
@@ -138,8 +141,8 @@ gst_filesink_class_init (GstFileSinkClass *klass)
 
   gobject_class->set_property = gst_filesink_set_property;
   gobject_class->get_property = gst_filesink_get_property;
+  gobject_class->dispose      = gst_filesink_dispose;
 }
-
 static void 
 gst_filesink_init (GstFileSink *filesink) 
 {
@@ -158,7 +161,43 @@ gst_filesink_init (GstFileSink *filesink)
   filesink->filename = NULL;
   filesink->file = NULL;
 }
+static void
+gst_filesink_dispose (GObject *object)
+{
+  GstFileSink *sink = GST_FILESINK (object);
 
+  G_OBJECT_CLASS (parent_class)->dispose (object);
+  
+  g_free (sink->uri);
+  sink->uri = NULL;
+  g_free (sink->filename);
+  sink->filename = NULL;
+}
+static gboolean
+gst_filesink_set_location (GstFileSink *sink, const gchar *location)
+{
+  /* the element must be stopped or paused in order to do this */
+  if (GST_STATE (sink) > GST_STATE_PAUSED)
+    return FALSE;
+  if (GST_STATE (sink) == GST_STATE_PAUSED &&
+      GST_FLAG_IS_SET (sink, GST_FILESINK_OPEN))
+    return FALSE;
+
+  g_free (sink->filename);
+  g_free (sink->uri);
+  if (location != NULL) {
+    sink->filename = g_strdup (location);
+    sink->uri = gst_uri_construct ("file", location);
+  } else {
+    sink->filename = NULL;
+    sink->uri = NULL;
+  }
+  
+  if (GST_STATE (sink) == GST_STATE_PAUSED)
+    gst_filesink_open_file (sink);
+
+  return TRUE;
+}
 static void
 gst_filesink_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
 {
@@ -169,16 +208,7 @@ gst_filesink_set_property (GObject *object, guint prop_id, const GValue *value,
 
   switch (prop_id) {
     case ARG_LOCATION:
-      /* the element must be stopped or paused in order to do this */
-      g_return_if_fail (GST_STATE (sink) <= GST_STATE_PAUSED);
-      if (GST_STATE (sink) == GST_STATE_PAUSED)
-        g_return_if_fail (!GST_FLAG_IS_SET (sink, GST_FILESINK_OPEN));
-
-      if (sink->filename)
-	g_free (sink->filename);
-      sink->filename = g_strdup (g_value_get_string (value));
-      if (GST_STATE (sink) == GST_STATE_PAUSED)
-        gst_filesink_open_file (sink);   
+      gst_filesink_set_location (sink, g_value_get_string (value));
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -212,20 +242,20 @@ gst_filesink_open_file (GstFileSink *sink)
   g_return_val_if_fail (!GST_FLAG_IS_SET (sink, GST_FILESINK_OPEN), FALSE);
 
   /* open the file */
-  if (!sink->filename)
+  if (sink->filename == NULL || sink->filename[0] == '\0')
   {
-    gst_element_error (GST_ELEMENT (sink),
-		       "Error opening file: no file given");
+    GST_ELEMENT_ERROR (sink, RESOURCE, NOT_FOUND,
+                         (_("No file name specified for writing.")), (NULL));
     return FALSE;
   }
 
   sink->file = fopen (sink->filename, "w");
   if (sink->file == NULL) {
-    gst_element_error (GST_ELEMENT (sink),
-		       "Error opening file %s: %s",
-		       sink->filename, g_strerror(errno));
+    GST_ELEMENT_ERROR (sink, RESOURCE, OPEN_WRITE,
+                         (_("Could not open file \"%s\" for writing."), sink->filename),
+                         GST_ERROR_SYSTEM);
     return FALSE;
-  } 
+  }
 
   GST_FLAG_SET (sink, GST_FILESINK_OPEN);
 
@@ -241,9 +271,9 @@ gst_filesink_close_file (GstFileSink *sink)
 
   if (fclose (sink->file) != 0)
   {
-    gst_element_error (GST_ELEMENT (sink),
-		       "Error closing file %s: %s",
-		       sink->filename, g_strerror(errno));
+    GST_ELEMENT_ERROR (sink, RESOURCE, CLOSE,
+		       (_("Error closing file \"%s\"."), sink->filename),
+                       GST_ERROR_SYSTEM);
   }
   else {
     GST_FLAG_UNSET (sink, GST_FILESINK_OPEN);
@@ -308,9 +338,9 @@ gst_filesink_handle_event (GstPad *pad, GstEvent *event)
 
       if (GST_EVENT_SEEK_FLAGS (event) & GST_SEEK_FLAG_FLUSH)
         if (fflush (filesink->file))
-          gst_element_error (GST_ELEMENT (filesink),
-			     "Error flushing file %s: %s",
-			     filesink->filename, g_strerror(errno));
+          GST_ELEMENT_ERROR (filesink, RESOURCE, WRITE,
+			     (_("Error while writing to file \"%s\"."), filesink->filename),
+			     GST_ERROR_SYSTEM);
 
       switch (GST_EVENT_SEEK_METHOD(event))
       {
@@ -340,9 +370,9 @@ gst_filesink_handle_event (GstPad *pad, GstEvent *event)
     }
     case GST_EVENT_FLUSH:
       if (fflush (filesink->file)) {
-        gst_element_error (GST_ELEMENT (filesink),
-			   "Error flushing file %s: %s",
-			   filesink->filename, g_strerror(errno));
+          GST_ELEMENT_ERROR (filesink, RESOURCE, WRITE,
+			     (_("Error while writing to file \"%s\"."), filesink->filename),
+			     GST_ERROR_SYSTEM);
       }
       break;
     case GST_EVENT_EOS:
@@ -392,10 +422,11 @@ gst_filesink_chain (GstPad *pad, GstData *_data)
 			     GST_BUFFER_SIZE (buf) - bytes_written,
 			     filesink->file);
       if (wrote <= 0) {
-	gst_element_error (GST_ELEMENT (filesink),
-			   "Only %d of %d bytes written: %s",
-			   bytes_written, GST_BUFFER_SIZE (buf),
-			   strerror (errno));
+        GST_ELEMENT_ERROR (filesink, RESOURCE, WRITE,
+			     (_("Error while writing to file \"%s\"."), filesink->filename),
+			      ("Only %d of %d bytes written: %s",
+			       bytes_written, GST_BUFFER_SIZE (buf),
+			       strerror (errno)));
 	break;
       }
       bytes_written += wrote;
@@ -435,3 +466,54 @@ gst_filesink_change_state (GstElement *element)
 
   return GST_STATE_SUCCESS;
 }
+
+/*** GSTURIHANDLER INTERFACE *************************************************/
+
+static guint
+gst_filesink_uri_get_type (void)
+{
+  return GST_URI_SINK;
+}
+static gchar **
+gst_filesink_uri_get_protocols(void)
+{
+  static gchar *protocols[] = {"file", NULL};
+  return protocols;
+}
+static const gchar *
+gst_filesink_uri_get_uri (GstURIHandler *handler)
+{
+  GstFileSink *sink = GST_FILESINK (handler);
+  
+  return sink->uri;
+}
+static gboolean
+gst_filesink_uri_set_uri (GstURIHandler *handler, const gchar *uri)
+{
+  gchar *protocol, *location;
+  gboolean ret;
+  GstFileSink *sink = GST_FILESINK (handler);
+
+  protocol = gst_uri_get_protocol (uri);
+  if (strcmp (protocol, "file") != 0) {
+    g_free (protocol);
+    return FALSE;
+  }
+  g_free (protocol);
+  location = gst_uri_get_location (uri);
+  ret = gst_filesink_set_location (sink, location);
+  g_free (location);
+
+  return ret;
+}
+
+static void
+gst_filesink_uri_handler_init (gpointer g_iface, gpointer iface_data)
+{
+  GstURIHandlerInterface *iface = (GstURIHandlerInterface *) g_iface;
+
+  iface->get_type = gst_filesink_uri_get_type;
+  iface->get_protocols = gst_filesink_uri_get_protocols;
+  iface->get_uri = gst_filesink_uri_get_uri;
+  iface->set_uri = gst_filesink_uri_set_uri;
+}
