@@ -53,16 +53,17 @@ enum {
   /* FILL ME */
 };
 
-GST_PAD_TEMPLATE_FACTORY (tee_src_factory,
+GstStaticPadTemplate tee_src_template = GST_STATIC_PAD_TEMPLATE (
   "src%d",
   GST_PAD_SRC,
   GST_PAD_REQUEST,
-  GST_CAPS_ANY
+  GST_STATIC_CAPS_ANY
 );
 
-static void	gst_tee_base_init	(gpointer g_class);
-static void 	gst_tee_class_init	(GstTeeClass *klass);
-static void 	gst_tee_init		(GstTee *tee);
+#define _do_init(bla) \
+    GST_DEBUG_CATEGORY_INIT (gst_tee_debug, "tee", 0, "tee element");
+
+GST_BOILERPLATE_FULL (GstTee, gst_tee, GstElement, GST_TYPE_ELEMENT, _do_init);
 
 static GstPad* 	gst_tee_request_new_pad (GstElement *element, GstPadTemplate *temp, const gchar *unused);
 
@@ -74,39 +75,14 @@ static void 	gst_tee_get_property 	(GObject *object, guint prop_id,
 static void  	gst_tee_chain 		(GstPad *pad, GstData *_data);
 
 
-static GstElementClass *parent_class = NULL;
-/*static guint gst_tee_signals[LAST_SIGNAL] = { 0 };*/
-
-GType
-gst_tee_get_type(void) {
-  static GType tee_type = 0;
-
-  if (!tee_type) {
-    static const GTypeInfo tee_info = {
-      sizeof(GstTeeClass),
-      gst_tee_base_init,
-      NULL,
-      (GClassInitFunc)gst_tee_class_init,
-      NULL,
-      NULL,
-      sizeof(GstTee),
-      0,
-      (GInstanceInitFunc)gst_tee_init,
-    };
-    tee_type = g_type_register_static (GST_TYPE_ELEMENT, "GstTee", &tee_info, 0);
-  
-    GST_DEBUG_CATEGORY_INIT (gst_tee_debug, "tee", 0, "tee element");
-  }
-  return tee_type;
-}
-
 static void
 gst_tee_base_init (gpointer g_class)
 {
   GstElementClass *gstelement_class = GST_ELEMENT_CLASS (g_class);
   
   gst_element_class_set_details (gstelement_class, &gst_tee_details);
-  gst_element_class_add_pad_template (gstelement_class, GST_PAD_TEMPLATE_GET (tee_src_factory));
+  gst_element_class_add_pad_template (gstelement_class,
+      gst_static_pad_template_get (&tee_src_template));
 }
 static void
 gst_tee_class_init (GstTeeClass *klass) 
@@ -117,14 +93,13 @@ gst_tee_class_init (GstTeeClass *klass)
   gobject_class = (GObjectClass*)klass;
   gstelement_class = (GstElementClass*)klass;
 
-  parent_class = g_type_class_ref(GST_TYPE_ELEMENT);
 
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_NUM_PADS,
     g_param_spec_int ("num_pads", "num_pads", "num_pads",
                       0, G_MAXINT, 0, G_PARAM_READABLE)); 
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_SILENT,
     g_param_spec_boolean ("silent", "silent", "silent",
-                      FALSE, G_PARAM_READWRITE));
+                      TRUE, G_PARAM_CONSTRUCT | G_PARAM_READWRITE));
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_LAST_MESSAGE,
     g_param_spec_string ("last_message", "last_message", "last_message",
 			 NULL, G_PARAM_READABLE));
@@ -136,102 +111,15 @@ gst_tee_class_init (GstTeeClass *klass)
   gstelement_class->request_new_pad = GST_DEBUG_FUNCPTR(gst_tee_request_new_pad);
 }
 
-static GstPadLinkReturn 
-gst_tee_sinklink (GstPad *pad, GstCaps *caps) 
-{
-  GstTee *tee;
-  const GList *pads;
-  GstPadLinkReturn set_retval;
-  GstCaps *caps1;
-  
-  GST_DEBUG ( "gst_tee_sinklink caps=%s", gst_caps_to_string(caps));
-
-  tee = GST_TEE (gst_pad_get_parent (pad));
-
-  if (!GST_CAPS_IS_FIXED (caps)) {
-    return GST_PAD_LINK_DELAYED;
-  }
-
-  if (GST_CAPS_IS_CHAINED (caps)) {
-    caps1 = gst_caps_copy_1(caps);
-    caps = caps1;
-  }
-
-  /* go through all the src pads */
-  pads = gst_element_get_pad_list (GST_ELEMENT (tee));
-
-  while (pads) {
-    GstPad *outpad = GST_PAD (pads->data);
-    pads = g_list_next (pads);
-		     
-    if (GST_PAD_DIRECTION (outpad) != GST_PAD_SRC || !GST_PAD_IS_LINKED (outpad))
-      continue;
-
-    if ((set_retval = gst_pad_try_set_caps (outpad, caps)) <= 0) {
-      return set_retval;
-    }
-  }
-  return GST_PAD_LINK_OK;
-}
-
-static GstPadLinkReturn 
-gst_tee_srclink (GstPad *pad, GstCaps *caps) 
-{
-  GstTee *tee;
-
-  GST_DEBUG ( "gst_tee_srclink caps=%s", gst_caps_to_string(caps));
-
-  tee = GST_TEE (gst_pad_get_parent (pad));
-
-  return gst_pad_proxy_link (tee->sinkpad, caps);
-}
-
-static GstCaps* 
-gst_tee_getcaps (GstPad *pad, GstCaps *filter) 
-{
-  GstCaps *caps = NULL;
-  GstTee *tee;
-  const GList *pads;
-
-  GST_DEBUG ( "gst_tee_getcaps");
-
-  tee = GST_TEE (gst_pad_get_parent (pad));
-
-  pads = gst_element_get_pad_list (GST_ELEMENT (tee));
-
-  while (pads) {
-    GstPad *srcpad = GST_PAD (pads->data);
-    GstPad *peer;
-    GstCaps *peercaps;
-    GstCaps *newcaps;
-
-    pads = g_list_next (pads);
-
-    peer = gst_pad_get_peer(srcpad);
-    if(!peer){
-      continue;
-    }
-
-    peercaps = gst_pad_get_caps (peer);
-    newcaps = gst_caps_intersect (caps, peercaps);
-    gst_caps_unref (caps);
-    gst_caps_sink (peercaps);
-    caps = newcaps;
-  }
-
-  return caps;
-}
-
 static void 
 gst_tee_init (GstTee *tee) 
 {
   tee->sinkpad = gst_pad_new ("sink", GST_PAD_SINK);
   gst_element_add_pad (GST_ELEMENT (tee), tee->sinkpad);
   gst_pad_set_chain_function (tee->sinkpad, GST_DEBUG_FUNCPTR (gst_tee_chain));
-  gst_pad_set_link_function (tee->sinkpad, GST_DEBUG_FUNCPTR (gst_tee_sinklink));
-  gst_pad_set_getcaps_function (tee->sinkpad, GST_DEBUG_FUNCPTR (gst_tee_getcaps));
+  gst_pad_set_link_function (tee->sinkpad, GST_DEBUG_FUNCPTR (gst_pad_proxy_pad_link));
+  gst_pad_set_getcaps_function (tee->sinkpad, GST_DEBUG_FUNCPTR (gst_pad_proxy_getcaps));
 
-  tee->silent = FALSE;
   tee->last_message = NULL;
 }
 
@@ -287,8 +175,8 @@ gst_tee_request_new_pad (GstElement *element, GstPadTemplate *templ, const gchar
   
   srcpad = gst_pad_new_from_template (templ, name);
   g_free (name);
-  gst_pad_set_link_function (srcpad, GST_DEBUG_FUNCPTR (gst_tee_srclink));
-  gst_pad_set_getcaps_function (srcpad, GST_DEBUG_FUNCPTR (gst_tee_getcaps));
+  gst_pad_set_link_function (srcpad, GST_DEBUG_FUNCPTR (gst_pad_proxy_pad_link));
+  gst_pad_set_getcaps_function (srcpad, GST_DEBUG_FUNCPTR (gst_pad_proxy_getcaps));
   gst_element_add_pad (GST_ELEMENT (tee), srcpad);
   GST_PAD_ELEMENT_PRIVATE (srcpad) = NULL;
 
@@ -312,6 +200,7 @@ gst_tee_set_property (GObject *object, guint prop_id, const GValue *value, GPara
   switch (prop_id) {
     case ARG_SILENT:
       tee->silent = g_value_get_boolean (value);
+      g_object_notify (G_OBJECT (tee), "silent");
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
