@@ -27,17 +27,14 @@
 #include "gstbuffer.h"
 #include "gstmemchunk.h"
 #include "gstinfo.h"
-#include "gstbufferpool-default.h"
 
 GType _gst_buffer_type;
-GType _gst_buffer_pool_type;
 
 #ifndef GST_DISABLE_TRACE
 /* #define GST_WITH_ALLOC_TRACE  */
 #include "gsttrace.h"
 
 static GstAllocTrace *_gst_buffer_trace;
-static GstAllocTrace *_gst_buffer_pool_trace;
 #endif
 
 static GstMemChunk *chunk;
@@ -49,19 +46,14 @@ _gst_buffer_initialize (void)
 		       (GBoxedCopyFunc) gst_data_ref,
 		       (GBoxedFreeFunc) gst_data_unref);
 
-  _gst_buffer_pool_type = g_boxed_type_register_static ("GstBufferPool",
-		            (GBoxedCopyFunc) gst_data_ref,
-			    (GBoxedFreeFunc) gst_data_unref);
-
 #ifndef GST_DISABLE_TRACE
   _gst_buffer_trace = gst_alloc_trace_register (GST_BUFFER_TRACE_NAME);
-  _gst_buffer_pool_trace = gst_alloc_trace_register (GST_BUFFER_POOL_TRACE_NAME);
 #endif
 
   chunk = gst_mem_chunk_new ("GstBufferChunk", sizeof (GstBuffer), 
                              sizeof (GstBuffer) * 200, 0);
 
-  GST_CAT_INFO (GST_CAT_BUFFER, "Buffers are initialized now");
+  GST_CAT_LOG (GST_CAT_BUFFER, "Buffers are initialized now");
 }
 
 GType
@@ -70,20 +62,10 @@ gst_buffer_get_type (void)
   return _gst_buffer_type;
 }
 
-static void
-_gst_buffer_free_to_pool (GstBuffer *buffer)
-{
-  GstBufferPool *pool = buffer->pool;
-
-  pool->buffer_free (pool, buffer, pool->user_data);
-
-  gst_data_unref (GST_DATA (pool));
-}
-
 static void
 _gst_buffer_sub_free (GstBuffer *buffer)
 {
-  gst_data_unref (GST_DATA (buffer->pool_private));
+  gst_data_unref (GST_DATA (buffer->buffer_private));
 
   GST_BUFFER_DATA (buffer) = NULL;
   GST_BUFFER_SIZE (buffer) = 0;
@@ -102,7 +84,6 @@ _gst_buffer_sub_free (GstBuffer *buffer)
  *
  * Frees the memory associated with the buffer including the buffer data,
  * unless the GST_BUFFER_DONTFREE flags was set or the buffer data is NULL.
- * This function is used by buffer pools.
  */
 void
 gst_buffer_default_free (GstBuffer *buffer)
@@ -110,8 +91,11 @@ gst_buffer_default_free (GstBuffer *buffer)
   g_return_if_fail (buffer != NULL);
 
   /* free our data */
-  if (!GST_BUFFER_FLAG_IS_SET (buffer, GST_BUFFER_DONTFREE) && GST_BUFFER_DATA (buffer)) 
+  if (GST_BUFFER_FREE_DATA_FUNC (buffer)) {
+    GST_BUFFER_FREE_DATA_FUNC (buffer) (buffer);
+  } else if (!GST_BUFFER_FLAG_IS_SET (buffer, GST_BUFFER_DONTFREE)) { 
     g_free (GST_BUFFER_DATA (buffer));
+  }
 
   /* set to safe values */
   GST_BUFFER_DATA (buffer) = NULL;
@@ -125,18 +109,30 @@ gst_buffer_default_free (GstBuffer *buffer)
 #endif
 }
 
-static GstBuffer*
-_gst_buffer_copy_from_pool (GstBuffer *buffer)
+/**
+ * gst_buffer_stamp:
+ * @dest: buffer to stamp
+ * @src: buffer to stamp from
+ *
+ * Copies additional information (timestamps and offsets) from one buffer to
+ * the other.
+ */
+void
+gst_buffer_stamp (GstBuffer *dest, const GstBuffer *src)
 {
-  return buffer->pool->buffer_copy (buffer->pool, buffer, buffer->pool->user_data);
+  g_return_if_fail (dest != NULL);
+  g_return_if_fail (src != NULL);
+  
+  GST_BUFFER_TIMESTAMP (dest) 	 = GST_BUFFER_TIMESTAMP (src);
+  GST_BUFFER_DURATION (dest) 	 = GST_BUFFER_DURATION (src);
+  GST_BUFFER_OFFSET (dest) 	 = GST_BUFFER_OFFSET (src);
+  GST_BUFFER_OFFSET_END (dest) 	 = GST_BUFFER_OFFSET_END (src);
 }
-
 /**
  * gst_buffer_default_copy:
  * @buffer: a #GstBuffer to make a copy of.
  *
  * Make a full newly allocated copy of the given buffer, data and all.
- * This function is used by buffer pools.
  *
  * Returns: the new #GstBuffer.
  */
@@ -164,11 +160,10 @@ gst_buffer_default_copy (GstBuffer *buffer)
                                              GST_BUFFER_SIZE (buffer));
   GST_BUFFER_SIZE (copy)  	 = GST_BUFFER_SIZE (buffer);
   GST_BUFFER_MAXSIZE (copy) 	 = GST_BUFFER_SIZE (buffer);
-  GST_BUFFER_TIMESTAMP (copy) 	 = GST_BUFFER_TIMESTAMP (buffer);
-  GST_BUFFER_DURATION (copy) 	 = GST_BUFFER_DURATION (buffer);
-  GST_BUFFER_OFFSET (copy) 	 = GST_BUFFER_OFFSET (buffer);
-  GST_BUFFER_BUFFERPOOL (copy)   = NULL;
-  GST_BUFFER_POOL_PRIVATE (copy) = NULL;
+
+  gst_buffer_stamp (copy, buffer);
+  GST_BUFFER_FREE_DATA_FUNC (copy) = NULL;
+  GST_BUFFER_PRIVATE (copy) = NULL;
 
   return copy;
 }
@@ -204,8 +199,9 @@ gst_buffer_new (void)
   GST_BUFFER_TIMESTAMP (newbuf)    = GST_CLOCK_TIME_NONE;
   GST_BUFFER_DURATION (newbuf)     = GST_CLOCK_TIME_NONE;
   GST_BUFFER_OFFSET (newbuf)       = GST_BUFFER_OFFSET_NONE;
-  GST_BUFFER_BUFFERPOOL (newbuf)   = NULL;
-  GST_BUFFER_POOL_PRIVATE (newbuf) = NULL;
+  GST_BUFFER_OFFSET_END (newbuf)   = GST_BUFFER_OFFSET_NONE;
+  GST_BUFFER_FREE_DATA_FUNC (newbuf) = NULL;
+  GST_BUFFER_PRIVATE (newbuf) = NULL;
 
   return newbuf;
 }
@@ -232,42 +228,6 @@ gst_buffer_new_and_alloc (guint size)
   return newbuf;
 }
 
-/**
- * gst_buffer_new_from_pool:
- * @pool: a #GstBufferPool to use.
- * @offset: the offset of the new buffer.
- * @size: the size of the new buffer.
- *
- * Creates a newly allocated buffer using the specified buffer pool, 
- * offset and size.
- *
- * Returns: the new #GstBuffer, or NULL if there was an error.
- */
-GstBuffer*
-gst_buffer_new_from_pool (GstBufferPool *pool, 
-		          guint64 offset, guint size)
-{
-  GstBuffer *buffer;
-  
-  g_return_val_if_fail (pool != NULL, NULL);
-
-  gst_data_ref (GST_DATA (pool));
-
-  buffer = pool->buffer_new (pool, offset, size, pool->user_data);
-  if (!buffer)
-    return NULL;
-
-  GST_BUFFER_BUFFERPOOL (buffer) = pool;
-
-  /* override the buffer refcount functions with those from the pool (if any) */
-  if (pool->buffer_free)
-    GST_DATA (buffer)->free = (GstDataFreeFunction)_gst_buffer_free_to_pool;
-  if (pool->buffer_copy)
-    GST_DATA (buffer)->copy = (GstDataCopyFunction)_gst_buffer_copy_from_pool;
-
-  return buffer;
-}
-
 /**
  * gst_buffer_create_sub:
  * @parent: a parent #GstBuffer to create a subbuffer from.
@@ -297,7 +257,7 @@ gst_buffer_create_sub (GstBuffer *parent, guint offset, guint size)
   buffer_data = parent->data + offset;
   /* make sure we're child not child from a child buffer */
   while (GST_BUFFER_FLAG_IS_SET (parent, GST_BUFFER_SUBBUFFER)) {
-    parent = GST_BUFFER (parent->pool_private);
+    parent = GST_BUFFER (parent->buffer_private);
   }
   /* ref the real parent */
   gst_data_ref (GST_DATA (parent));
@@ -308,7 +268,7 @@ gst_buffer_create_sub (GstBuffer *parent, guint offset, guint size)
   gst_alloc_trace_new (_gst_buffer_trace, buffer);
 #endif
 
-  GST_CAT_LOG (GST_CAT_BUFFER, "new subbuffer %p", buffer);
+  GST_CAT_LOG (GST_CAT_BUFFER, "new subbuffer %p (parent %p)", buffer, parent);
 
   /* make sure nobody overwrites data in the new buffer 
    * by setting the READONLY flag */
@@ -323,8 +283,8 @@ gst_buffer_create_sub (GstBuffer *parent, guint offset, guint size)
   GST_BUFFER_DATA (buffer)         = buffer_data;
   GST_BUFFER_SIZE (buffer)         = size;
   GST_BUFFER_MAXSIZE (buffer)      = size;
-  GST_BUFFER_BUFFERPOOL (buffer)   = NULL;
-  GST_BUFFER_POOL_PRIVATE (buffer) = parent;
+  GST_BUFFER_FREE_DATA_FUNC (buffer) = NULL;
+  GST_BUFFER_PRIVATE (buffer) = parent;
   /* we can copy the timestamp and offset if the new buffer starts at
    * offset 0 */
   if (offset == 0) {
@@ -335,11 +295,16 @@ gst_buffer_create_sub (GstBuffer *parent, guint offset, guint size)
     GST_BUFFER_TIMESTAMP (buffer)    = GST_CLOCK_TIME_NONE;
     GST_BUFFER_OFFSET (buffer)       = GST_BUFFER_OFFSET_NONE;
   }
-  GST_BUFFER_DURATION (buffer)     = GST_CLOCK_TIME_NONE;
 
-  /* make sure nobody overwrites data as it would overwrite in the parent.
-   * data in parent cannot be overwritten because we hold a ref */
-  GST_DATA_FLAG_SET (parent, GST_DATA_READONLY);
+  GST_BUFFER_DURATION (buffer)     = GST_CLOCK_TIME_NONE;
+  GST_BUFFER_OFFSET_END (buffer)   = GST_BUFFER_OFFSET_NONE;
+
+  if (GST_BUFFER_FLAG_IS_SET (parent, GST_BUFFER_DONTKEEP)) {
+    GST_BUFFER_FLAG_SET (buffer, GST_BUFFER_DONTKEEP);
+  }
+  if (GST_BUFFER_FLAG_IS_SET (parent, GST_BUFFER_READONLY)) {
+    GST_BUFFER_FLAG_SET (buffer, GST_BUFFER_READONLY);
+  }
 
   return buffer;
 }
@@ -391,7 +356,7 @@ gst_buffer_is_span_fast (GstBuffer *buf1, GstBuffer *buf2)
   /* it's only fast if we have subbuffers of the same parent */
   return ((GST_BUFFER_FLAG_IS_SET (buf1, GST_BUFFER_SUBBUFFER)) &&
           (GST_BUFFER_FLAG_IS_SET (buf2, GST_BUFFER_SUBBUFFER)) &&
- 	  (buf1->pool_private == buf2->pool_private) &&
+ 	  (buf1->buffer_private == buf2->buffer_private) &&
           ((buf1->data + buf1->size) == buf2->data));
 }
 
@@ -428,7 +393,7 @@ gst_buffer_span (GstBuffer *buf1, guint32 offset, GstBuffer *buf2, guint32 len)
 
   /* if the two buffers have the same parent and are adjacent */
   if (gst_buffer_is_span_fast (buf1, buf2)) {
-    GstBuffer *parent = GST_BUFFER (buf1->pool_private);
+    GstBuffer *parent = GST_BUFFER (buf1->buffer_private);
     /* we simply create a subbuffer of the common parent */
     newbuf = gst_buffer_create_sub (parent, 
 	                            buf1->data - parent->data + offset, len);
@@ -453,153 +418,19 @@ gst_buffer_span (GstBuffer *buf1, guint32 offset, GstBuffer *buf2, guint32 len)
   /* if we completely merged the two buffers (appended), we can
    * calculate the duration too. Also make sure we's not messing with
    * invalid DURATIONS */
-  if (offset == 0 && buf1->size + buf2->size == len &&
-      GST_BUFFER_DURATION_IS_VALID (buf1) &&
-      GST_BUFFER_DURATION_IS_VALID (buf2)) 
-  {
-    /* add duration */
-    GST_BUFFER_DURATION (newbuf) = GST_BUFFER_DURATION (buf1) + 
-                                   GST_BUFFER_DURATION (buf2);
+  if (offset == 0 && buf1->size + buf2->size == len) {
+    if (GST_BUFFER_DURATION_IS_VALID (buf1) &&
+	GST_BUFFER_DURATION_IS_VALID (buf2)) {
+      /* add duration */
+      GST_BUFFER_DURATION (newbuf) = GST_BUFFER_DURATION (buf1) + 
+				    GST_BUFFER_DURATION (buf2);
+    }
+    if (GST_BUFFER_OFFSET_END_IS_VALID (buf2)) {
+      /* add offset_end */
+      GST_BUFFER_OFFSET_END (newbuf) = GST_BUFFER_OFFSET_END (buf2);
+    }
   }
 
   return newbuf;
 }
 
-GType
-gst_buffer_pool_get_type (void)
-{
-  return _gst_buffer_pool_type;
-}
-
-/**
- * gst_buffer_pool_default_free:
- * @pool: a #GstBufferPool to free.
- *
- * Frees the memory associated with the bufferpool.
- */
-void
-gst_buffer_pool_default_free (GstBufferPool *pool)
-{
-  g_return_if_fail (pool != NULL);
-
-  _GST_DATA_DISPOSE (GST_DATA (pool));
-  g_free (pool);
-#ifndef GST_DISABLE_TRACE
-  gst_alloc_trace_free (_gst_buffer_pool_trace, pool);
-#endif
-}
-
-/** 
- * gst_buffer_pool_new:
- * @free: the #GstDataFreeFunction to free the buffer pool.
- * @copy: the #GstDataCopyFunction to copy the buffer pool.
- * @buffer_new: the #GstBufferPoolBufferNewFunction to create a new buffer 
- *              from this pool
- * @buffer_copy: the #GstBufferPoolBufferCopyFunction to copy a buffer
- *               from this pool
- * @buffer_free: the #GstBufferPoolBufferFreeFunction to free a buffer 
- *               in this pool
- * @user_data: the user data gpointer passed to buffer_* functions.
- *
- * Creates a new buffer pool with the given functions.
- *
- * Returns: a new #GstBufferPool, or NULL on error.
- */
-GstBufferPool*	
-gst_buffer_pool_new (GstDataFreeFunction free,
-		     GstDataCopyFunction copy,
-                     GstBufferPoolBufferNewFunction buffer_new,
-                     GstBufferPoolBufferCopyFunction buffer_copy,
-                     GstBufferPoolBufferFreeFunction buffer_free,
-		     gpointer user_data)
-{
-  GstBufferPool *pool;
-
-  /* we need at least a buffer_new function */
-  g_return_val_if_fail (buffer_new != NULL, NULL);
-
-  pool = g_new0 (GstBufferPool, 1);
-#ifndef GST_DISABLE_TRACE
-  gst_alloc_trace_new (_gst_buffer_pool_trace, pool);
-#endif
-
-  GST_CAT_DEBUG (GST_CAT_BUFFER, "allocating new buffer pool %p\n", pool);
-        
-  /* init data struct */
-  _GST_DATA_INIT (GST_DATA (pool), 
-		  _gst_buffer_pool_type,
-		  0,
-		  (free ? free : (GstDataFreeFunction) gst_buffer_pool_default_free),
-		  copy);
-	    
-  /* set functions */
-  pool->buffer_new = buffer_new;
-  pool->buffer_copy = buffer_copy;
-  pool->buffer_free = buffer_free;
-  pool->user_data = user_data;
-		    
-  return pool;
-}
-
-/**
- * gst_buffer_pool_is_active:
- * @pool: the #GstBufferPool to query.
- *
- * Queries if the given buffer pool is active.
- *
- * Returns: TRUE if the pool is active.
- */
-gboolean
-gst_buffer_pool_is_active (GstBufferPool *pool)
-{
-  g_return_val_if_fail (pool != NULL, FALSE);
-
-  return pool->active;
-}
-
-/**
- * gst_buffer_pool_set_active:
- * @pool: a #GstBufferPool to set the activity status on.
- * @active: the new status of the pool.
- *
- * Sets the given pool to the active or inactive state depending on the
- * active parameter.
- */
-void
-gst_buffer_pool_set_active (GstBufferPool *pool, gboolean active)
-{
-  g_return_if_fail (pool != NULL);
-
-  pool->active = active;
-}
-
-/**
- * gst_buffer_pool_set_user_data:
- * @pool: the #GstBufferPool to set the user data for.
- * @user_data: the user_data to set on the buffer pool.
- *
- * Sets the given user data on the buffer pool.
- */
-void
-gst_buffer_pool_set_user_data (GstBufferPool *pool, gpointer user_data)
-{
-  g_return_if_fail (pool != NULL);
-
-  pool->user_data = user_data;
-}
-
-/**
- * gst_buffer_pool_get_user_data:
- * @pool: the #GstBufferPool to get the user data for.
- *
- * Gets the user data of the buffer pool.
- * 
- * Returns: the user data associated with this buffer pool.
- */
-gpointer
-gst_buffer_pool_get_user_data (GstBufferPool *pool)
-{
-  g_return_val_if_fail (pool != NULL, NULL);
-
-  return pool->user_data;
-}
