@@ -52,7 +52,7 @@ typedef gpointer 	GstClockID;
 #define GST_TIME_TO_TIMEVAL(t,tv)			\
 G_STMT_START { 						\
   (tv).tv_sec  =  (t) / GST_SECOND;			\
-  (tv).tv_usec = ((t) / GST_USECOND) % GST_MSECOND;	\
+  (tv).tv_usec = ((t) - (tv).tv_sec * GST_SECOND) / GST_USECOND;	\
 } G_STMT_END
 
 #define GST_CLOCK_ENTRY_TRACE_NAME "GstClockEntry"
@@ -163,27 +163,21 @@ struct _GstClockClass {
 
 GType           	gst_clock_get_type 		(void);
 
-#ifndef GST_DISABLE_DEPRECATED
 gdouble			gst_clock_set_speed		(GstClock *clock, gdouble speed);
 gdouble 		gst_clock_get_speed		(GstClock *clock);
-#endif
 
 guint64			gst_clock_set_resolution	(GstClock *clock, guint64 resolution);
 guint64			gst_clock_get_resolution	(GstClock *clock);
 
-#ifndef GST_DISABLE_DEPRECATED
 void 			gst_clock_set_active		(GstClock *clock, gboolean active);
 gboolean 		gst_clock_is_active		(GstClock *clock);
 void 			gst_clock_reset			(GstClock *clock);
 gboolean		gst_clock_handle_discont	(GstClock *clock, guint64 time);
-#endif
 
 GstClockTime		gst_clock_get_time		(GstClock *clock);
 GstClockTime		gst_clock_get_event_time	(GstClock *clock);
 
 
-/* FIXME: deprecate? */
-#ifndef GST_DISABLE_DEPRECATED
 GstClockID		gst_clock_get_next_id		(GstClock *clock);
 
 /* creating IDs that can be used to get notifications */
@@ -203,7 +197,6 @@ GstClockReturn		gst_clock_id_wait_async		(GstClockID id,
 void 			gst_clock_id_unschedule		(GstClockID id);
 void			gst_clock_id_unlock		(GstClockID id);
 void			gst_clock_id_free		(GstClockID id);
-#endif
 
 
 G_END_DECLS
