@@ -21,76 +21,6 @@ gst_object_flags_get_type (void)
 }
 
 
-/* enumerations from "gsttypes.h" */
-GType
-gst_element_state_get_type (void)
-{
-  static GType etype = 0;
-  if (etype == 0) {
-    static const GFlagsValue values[] = {
-      { GST_STATE_VOID_PENDING, "GST_STATE_VOID_PENDING", "void-pending" },
-      { GST_STATE_NULL, "GST_STATE_NULL", "null" },
-      { GST_STATE_READY, "GST_STATE_READY", "ready" },
-      { GST_STATE_PAUSED, "GST_STATE_PAUSED", "paused" },
-      { GST_STATE_PLAYING, "GST_STATE_PLAYING", "playing" },
-      { 0, NULL, NULL }
-    };
-    etype = g_flags_register_static ("GstElementState", values);
-  }
-  return etype;
-}
-
-GType
-gst_element_state_return_get_type (void)
-{
-  static GType etype = 0;
-  if (etype == 0) {
-    static const GEnumValue values[] = {
-      { GST_STATE_FAILURE, "GST_STATE_FAILURE", "failure" },
-      { GST_STATE_SUCCESS, "GST_STATE_SUCCESS", "success" },
-      { GST_STATE_ASYNC, "GST_STATE_ASYNC", "async" },
-      { 0, NULL, NULL }
-    };
-    etype = g_enum_register_static ("GstElementStateReturn", values);
-  }
-  return etype;
-}
-
-GType
-gst_result_get_type (void)
-{
-  static GType etype = 0;
-  if (etype == 0) {
-    static const GEnumValue values[] = {
-      { GST_RESULT_OK, "GST_RESULT_OK", "ok" },
-      { GST_RESULT_NOK, "GST_RESULT_NOK", "nok" },
-      { GST_RESULT_NOT_IMPL, "GST_RESULT_NOT_IMPL", "not-impl" },
-      { 0, NULL, NULL }
-    };
-    etype = g_enum_register_static ("GstResult", values);
-  }
-  return etype;
-}
-
-
-/* enumerations from "gstautoplug.h" */
-GType
-gst_autoplug_flags_get_type (void)
-{
-  static GType etype = 0;
-  if (etype == 0) {
-    static const GEnumValue values[] = {
-      { GST_AUTOPLUG_TO_CAPS, "GST_AUTOPLUG_TO_CAPS", "to-caps" },
-      { GST_AUTOPLUG_TO_RENDERER, "GST_AUTOPLUG_TO_RENDERER", "to-renderer" },
-      { GST_AUTOPLUG_FLAG_LAST, "GST_AUTOPLUG_FLAG_LAST", "flag-last" },
-      { 0, NULL, NULL }
-    };
-    etype = g_enum_register_static ("GstAutoplugFlags", values);
-  }
-  return etype;
-}
-
-
 /* enumerations from "gstbin.h" */
 GType
 gst_bin_flags_get_type (void)
@@ -122,9 +52,8 @@ gst_buffer_flag_get_type (void)
       { GST_BUFFER_SUBBUFFER, "GST_BUFFER_SUBBUFFER", "subbuffer" },
       { GST_BUFFER_ORIGINAL, "GST_BUFFER_ORIGINAL", "original" },
       { GST_BUFFER_DONTFREE, "GST_BUFFER_DONTFREE", "dontfree" },
-      { GST_BUFFER_DISCONTINUOUS, "GST_BUFFER_DISCONTINUOUS", "discontinuous" },
       { GST_BUFFER_KEY_UNIT, "GST_BUFFER_KEY_UNIT", "key-unit" },
-      { GST_BUFFER_PREROLL, "GST_BUFFER_PREROLL", "preroll" },
+      { GST_BUFFER_DONTKEEP, "GST_BUFFER_DONTKEEP", "dontkeep" },
       { GST_BUFFER_FLAG_LAST, "GST_BUFFER_FLAG_LAST", "flag-last" },
       { 0, NULL, NULL }
     };
@@ -134,23 +63,6 @@ gst_buffer_flag_get_type (void)
 }
 
 
-/* enumerations from "gstcaps.h" */
-GType
-gst_caps_flags_get_type (void)
-{
-  static GType etype = 0;
-  if (etype == 0) {
-    static const GFlagsValue values[] = {
-      { GST_CAPS_UNUSED, "GST_CAPS_UNUSED", "unused" },
-      { GST_CAPS_FLOATING, "GST_CAPS_FLOATING", "floating" },
-      { 0, NULL, NULL }
-    };
-    etype = g_flags_register_static ("GstCapsFlags", values);
-  }
-  return etype;
-}
-
-
 /* enumerations from "gstclock.h" */
 GType
 gst_clock_entry_status_get_type (void)
@@ -274,7 +186,7 @@ gst_element_flags_get_type (void)
       { GST_ELEMENT_SCHEDULER_PRIVATE1, "GST_ELEMENT_SCHEDULER_PRIVATE1", "scheduler-private1" },
       { GST_ELEMENT_SCHEDULER_PRIVATE2, "GST_ELEMENT_SCHEDULER_PRIVATE2", "scheduler-private2" },
       { GST_ELEMENT_LOCKED_STATE, "GST_ELEMENT_LOCKED_STATE", "locked-state" },
-      { GST_ELEMENT_ERROR, "GST_ELEMENT_ERROR", "error" },
+      { GST_ELEMENT_IN_ERROR, "GST_ELEMENT_IN_ERROR", "in-error" },
       { GST_ELEMENT_FLAG_LAST, "GST_ELEMENT_FLAG_LAST", "flag-last" },
       { 0, NULL, NULL }
     };
@@ -284,6 +196,106 @@ gst_element_flags_get_type (void)
 }
 
 
+/* enumerations from "gsterror.h" */
+GType
+gst_core_error_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { GST_CORE_ERROR_FAILED, "GST_CORE_ERROR_FAILED", "failed" },
+      { GST_CORE_ERROR_TOO_LAZY, "GST_CORE_ERROR_TOO_LAZY", "too-lazy" },
+      { GST_CORE_ERROR_NOT_IMPLEMENTED, "GST_CORE_ERROR_NOT_IMPLEMENTED", "not-implemented" },
+      { GST_CORE_ERROR_STATE_CHANGE, "GST_CORE_ERROR_STATE_CHANGE", "state-change" },
+      { GST_CORE_ERROR_PAD, "GST_CORE_ERROR_PAD", "pad" },
+      { GST_CORE_ERROR_THREAD, "GST_CORE_ERROR_THREAD", "thread" },
+      { GST_CORE_ERROR_SCHEDULER, "GST_CORE_ERROR_SCHEDULER", "scheduler" },
+      { GST_CORE_ERROR_NEGOTIATION, "GST_CORE_ERROR_NEGOTIATION", "negotiation" },
+      { GST_CORE_ERROR_EVENT, "GST_CORE_ERROR_EVENT", "event" },
+      { GST_CORE_ERROR_SEEK, "GST_CORE_ERROR_SEEK", "seek" },
+      { GST_CORE_ERROR_CAPS, "GST_CORE_ERROR_CAPS", "caps" },
+      { GST_CORE_ERROR_TAG, "GST_CORE_ERROR_TAG", "tag" },
+      { GST_CORE_ERROR_NUM_ERRORS, "GST_CORE_ERROR_NUM_ERRORS", "num-errors" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("GstCoreError", values);
+  }
+  return etype;
+}
+
+GType
+gst_library_error_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { GST_LIBRARY_ERROR_FAILED, "GST_LIBRARY_ERROR_FAILED", "failed" },
+      { GST_LIBRARY_ERROR_TOO_LAZY, "GST_LIBRARY_ERROR_TOO_LAZY", "too-lazy" },
+      { GST_LIBRARY_ERROR_INIT, "GST_LIBRARY_ERROR_INIT", "init" },
+      { GST_LIBRARY_ERROR_SHUTDOWN, "GST_LIBRARY_ERROR_SHUTDOWN", "shutdown" },
+      { GST_LIBRARY_ERROR_SETTINGS, "GST_LIBRARY_ERROR_SETTINGS", "settings" },
+      { GST_LIBRARY_ERROR_ENCODE, "GST_LIBRARY_ERROR_ENCODE", "encode" },
+      { GST_LIBRARY_ERROR_NUM_ERRORS, "GST_LIBRARY_ERROR_NUM_ERRORS", "num-errors" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("GstLibraryError", values);
+  }
+  return etype;
+}
+
+GType
+gst_resource_error_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { GST_RESOURCE_ERROR_FAILED, "GST_RESOURCE_ERROR_FAILED", "failed" },
+      { GST_RESOURCE_ERROR_TOO_LAZY, "GST_RESOURCE_ERROR_TOO_LAZY", "too-lazy" },
+      { GST_RESOURCE_ERROR_NOT_FOUND, "GST_RESOURCE_ERROR_NOT_FOUND", "not-found" },
+      { GST_RESOURCE_ERROR_BUSY, "GST_RESOURCE_ERROR_BUSY", "busy" },
+      { GST_RESOURCE_ERROR_OPEN_READ, "GST_RESOURCE_ERROR_OPEN_READ", "open-read" },
+      { GST_RESOURCE_ERROR_OPEN_WRITE, "GST_RESOURCE_ERROR_OPEN_WRITE", "open-write" },
+      { GST_RESOURCE_ERROR_OPEN_READ_WRITE, "GST_RESOURCE_ERROR_OPEN_READ_WRITE", "open-read-write" },
+      { GST_RESOURCE_ERROR_CLOSE, "GST_RESOURCE_ERROR_CLOSE", "close" },
+      { GST_RESOURCE_ERROR_READ, "GST_RESOURCE_ERROR_READ", "read" },
+      { GST_RESOURCE_ERROR_WRITE, "GST_RESOURCE_ERROR_WRITE", "write" },
+      { GST_RESOURCE_ERROR_SEEK, "GST_RESOURCE_ERROR_SEEK", "seek" },
+      { GST_RESOURCE_ERROR_SYNC, "GST_RESOURCE_ERROR_SYNC", "sync" },
+      { GST_RESOURCE_ERROR_SETTINGS, "GST_RESOURCE_ERROR_SETTINGS", "settings" },
+      { GST_RESOURCE_ERROR_NUM_ERRORS, "GST_RESOURCE_ERROR_NUM_ERRORS", "num-errors" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("GstResourceError", values);
+  }
+  return etype;
+}
+
+GType
+gst_stream_error_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { GST_STREAM_ERROR_FAILED, "GST_STREAM_ERROR_FAILED", "failed" },
+      { GST_STREAM_ERROR_TOO_LAZY, "GST_STREAM_ERROR_TOO_LAZY", "too-lazy" },
+      { GST_STREAM_ERROR_NOT_IMPLEMENTED, "GST_STREAM_ERROR_NOT_IMPLEMENTED", "not-implemented" },
+      { GST_STREAM_ERROR_TYPE_NOT_FOUND, "GST_STREAM_ERROR_TYPE_NOT_FOUND", "type-not-found" },
+      { GST_STREAM_ERROR_WRONG_TYPE, "GST_STREAM_ERROR_WRONG_TYPE", "wrong-type" },
+      { GST_STREAM_ERROR_CODEC_NOT_FOUND, "GST_STREAM_ERROR_CODEC_NOT_FOUND", "codec-not-found" },
+      { GST_STREAM_ERROR_DECODE, "GST_STREAM_ERROR_DECODE", "decode" },
+      { GST_STREAM_ERROR_ENCODE, "GST_STREAM_ERROR_ENCODE", "encode" },
+      { GST_STREAM_ERROR_DEMUX, "GST_STREAM_ERROR_DEMUX", "demux" },
+      { GST_STREAM_ERROR_MUX, "GST_STREAM_ERROR_MUX", "mux" },
+      { GST_STREAM_ERROR_FORMAT, "GST_STREAM_ERROR_FORMAT", "format" },
+      { GST_STREAM_ERROR_NUM_ERRORS, "GST_STREAM_ERROR_NUM_ERRORS", "num-errors" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("GstStreamError", values);
+  }
+  return etype;
+}
+
+
 /* enumerations from "gstevent.h" */
 GType
 gst_event_type_get_type (void)
@@ -306,6 +318,7 @@ gst_event_type_get_type (void)
       { GST_EVENT_TS_OFFSET, "GST_EVENT_TS_OFFSET", "ts-offset" },
       { GST_EVENT_INTERRUPT, "GST_EVENT_INTERRUPT", "interrupt" },
       { GST_EVENT_NAVIGATION, "GST_EVENT_NAVIGATION", "navigation" },
+      { GST_EVENT_TAG, "GST_EVENT_TAG", "tag" },
       { 0, NULL, NULL }
     };
     etype = g_enum_register_static ("GstEventType", values);
@@ -628,6 +641,7 @@ gst_plugin_error_get_type (void)
     static const GEnumValue values[] = {
       { GST_PLUGIN_ERROR_MODULE, "GST_PLUGIN_ERROR_MODULE", "module" },
       { GST_PLUGIN_ERROR_DEPENDENCIES, "GST_PLUGIN_ERROR_DEPENDENCIES", "dependencies" },
+      { GST_PLUGIN_ERROR_NAME_MISMATCH, "GST_PLUGIN_ERROR_NAME_MISMATCH", "name-mismatch" },
       { 0, NULL, NULL }
     };
     etype = g_enum_register_static ("GstPluginError", values);
@@ -636,49 +650,6 @@ gst_plugin_error_get_type (void)
 }
 
 
-/* enumerations from "gstprops.h" */
-GType
-gst_props_type_get_type (void)
-{
-  static GType etype = 0;
-  if (etype == 0) {
-    static const GEnumValue values[] = {
-      { GST_PROPS_END_TYPE, "GST_PROPS_END_TYPE", "end-type" },
-      { GST_PROPS_INVALID_TYPE, "GST_PROPS_INVALID_TYPE", "invalid-type" },
-      { GST_PROPS_INT_TYPE, "GST_PROPS_INT_TYPE", "int-type" },
-      { GST_PROPS_FLOAT_TYPE, "GST_PROPS_FLOAT_TYPE", "float-type" },
-      { GST_PROPS_FOURCC_TYPE, "GST_PROPS_FOURCC_TYPE", "fourcc-type" },
-      { GST_PROPS_BOOLEAN_TYPE, "GST_PROPS_BOOLEAN_TYPE", "boolean-type" },
-      { GST_PROPS_STRING_TYPE, "GST_PROPS_STRING_TYPE", "string-type" },
-      { GST_PROPS_VAR_TYPE, "GST_PROPS_VAR_TYPE", "var-type" },
-      { GST_PROPS_LIST_TYPE, "GST_PROPS_LIST_TYPE", "list-type" },
-      { GST_PROPS_GLIST_TYPE, "GST_PROPS_GLIST_TYPE", "glist-type" },
-      { GST_PROPS_FLOAT_RANGE_TYPE, "GST_PROPS_FLOAT_RANGE_TYPE", "float-range-type" },
-      { GST_PROPS_INT_RANGE_TYPE, "GST_PROPS_INT_RANGE_TYPE", "int-range-type" },
-      { GST_PROPS_LAST_TYPE, "GST_PROPS_LAST_TYPE", "last-type" },
-      { 0, NULL, NULL }
-    };
-    etype = g_enum_register_static ("GstPropsType", values);
-  }
-  return etype;
-}
-
-GType
-gst_props_flags_get_type (void)
-{
-  static GType etype = 0;
-  if (etype == 0) {
-    static const GFlagsValue values[] = {
-      { GST_PROPS_FIXED, "GST_PROPS_FIXED", "fixed" },
-      { GST_PROPS_FLOATING, "GST_PROPS_FLOATING", "floating" },
-      { 0, NULL, NULL }
-    };
-    etype = g_flags_register_static ("GstPropsFlags", values);
-  }
-  return etype;
-}
-
-
 /* enumerations from "gstquery.h" */
 GType
 gst_query_type_get_type (void)
@@ -736,6 +707,47 @@ gst_scheduler_state_get_type (void)
 }
 
 
+/* enumerations from "gsttag.h" */
+GType
+gst_tag_merge_mode_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { GST_TAG_MERGE_UNDEFINED, "GST_TAG_MERGE_UNDEFINED", "undefined" },
+      { GST_TAG_MERGE_REPLACE_ALL, "GST_TAG_MERGE_REPLACE_ALL", "replace-all" },
+      { GST_TAG_MERGE_REPLACE, "GST_TAG_MERGE_REPLACE", "replace" },
+      { GST_TAG_MERGE_APPEND, "GST_TAG_MERGE_APPEND", "append" },
+      { GST_TAG_MERGE_PREPEND, "GST_TAG_MERGE_PREPEND", "prepend" },
+      { GST_TAG_MERGE_KEEP, "GST_TAG_MERGE_KEEP", "keep" },
+      { GST_TAG_MERGE_KEEP_ALL, "GST_TAG_MERGE_KEEP_ALL", "keep-all" },
+      { GST_TAG_MERGE_COUNT, "GST_TAG_MERGE_COUNT", "count" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("GstTagMergeMode", values);
+  }
+  return etype;
+}
+
+GType
+gst_tag_flag_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { GST_TAG_FLAG_UNDEFINED, "GST_TAG_FLAG_UNDEFINED", "undefined" },
+      { GST_TAG_FLAG_META, "GST_TAG_FLAG_META", "meta" },
+      { GST_TAG_FLAG_ENCODED, "GST_TAG_FLAG_ENCODED", "encoded" },
+      { GST_TAG_FLAG_DECODED, "GST_TAG_FLAG_DECODED", "decoded" },
+      { GST_TAG_FLAG_COUNT, "GST_TAG_FLAG_COUNT", "count" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("GstTagFlag", values);
+  }
+  return etype;
+}
+
+
 /* enumerations from "gstthread.h" */
 GType
 gst_thread_state_get_type (void)
@@ -772,6 +784,96 @@ gst_alloc_trace_flags_get_type (void)
 }
 
 
+/* enumerations from "gsttypefind.h" */
+GType
+gst_type_find_probability_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { GST_TYPE_FIND_MINIMUM, "GST_TYPE_FIND_MINIMUM", "minimum" },
+      { GST_TYPE_FIND_POSSIBLE, "GST_TYPE_FIND_POSSIBLE", "possible" },
+      { GST_TYPE_FIND_LIKELY, "GST_TYPE_FIND_LIKELY", "likely" },
+      { GST_TYPE_FIND_NEARLY_CERTAIN, "GST_TYPE_FIND_NEARLY_CERTAIN", "nearly-certain" },
+      { GST_TYPE_FIND_MAXIMUM, "GST_TYPE_FIND_MAXIMUM", "maximum" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("GstTypeFindProbability", values);
+  }
+  return etype;
+}
+
+
+/* enumerations from "gsttypes.h" */
+GType
+gst_element_state_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GFlagsValue values[] = {
+      { GST_STATE_VOID_PENDING, "GST_STATE_VOID_PENDING", "void-pending" },
+      { GST_STATE_NULL, "GST_STATE_NULL", "null" },
+      { GST_STATE_READY, "GST_STATE_READY", "ready" },
+      { GST_STATE_PAUSED, "GST_STATE_PAUSED", "paused" },
+      { GST_STATE_PLAYING, "GST_STATE_PLAYING", "playing" },
+      { 0, NULL, NULL }
+    };
+    etype = g_flags_register_static ("GstElementState", values);
+  }
+  return etype;
+}
+
+GType
+gst_element_state_return_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { GST_STATE_FAILURE, "GST_STATE_FAILURE", "failure" },
+      { GST_STATE_SUCCESS, "GST_STATE_SUCCESS", "success" },
+      { GST_STATE_ASYNC, "GST_STATE_ASYNC", "async" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("GstElementStateReturn", values);
+  }
+  return etype;
+}
+
+GType
+gst_result_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { GST_RESULT_OK, "GST_RESULT_OK", "ok" },
+      { GST_RESULT_NOK, "GST_RESULT_NOK", "nok" },
+      { GST_RESULT_NOT_IMPL, "GST_RESULT_NOT_IMPL", "not-impl" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("GstResult", values);
+  }
+  return etype;
+}
+
+
+/* enumerations from "gsturi.h" */
+GType
+gst_uri_type_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { GST_URI_UNKNOWN, "GST_URI_UNKNOWN", "unknown" },
+      { GST_URI_SINK, "GST_URI_SINK", "sink" },
+      { GST_URI_SRC, "GST_URI_SRC", "src" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("GstURIType", values);
+  }
+  return etype;
+}
+
+
 /* enumerations from "gstregistry.h" */
 GType
 gst_registry_return_get_type (void)
