@@ -58,9 +58,11 @@
 
 /* VOID:STRING (gstmarshal.list:4) */
 
-/* VOID:POINTER (gstmarshal.list:5) */
+/* VOID:BOXED (gstmarshal.list:5) */
 
-/* VOID:POINTER,OBJECT (gstmarshal.list:6) */
+/* VOID:POINTER (gstmarshal.list:6) */
+
+/* VOID:POINTER,OBJECT (gstmarshal.list:7) */
 void
 gst_marshal_VOID__POINTER_OBJECT (GClosure     *closure,
                                   GValue       *return_value,
@@ -97,9 +99,9 @@ gst_marshal_VOID__POINTER_OBJECT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT (gstmarshal.list:7) */
+/* VOID:OBJECT (gstmarshal.list:8) */
 
-/* VOID:OBJECT,PARAM (gstmarshal.list:8) */
+/* VOID:OBJECT,PARAM (gstmarshal.list:9) */
 void
 gst_marshal_VOID__OBJECT_PARAM (GClosure     *closure,
                                 GValue       *return_value,
@@ -136,7 +138,7 @@ gst_marshal_VOID__OBJECT_PARAM (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,POINTER (gstmarshal.list:9) */
+/* VOID:OBJECT,POINTER (gstmarshal.list:10) */
 void
 gst_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                   GValue       *return_value,
@@ -173,7 +175,44 @@ gst_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,POINTER,STRING (gstmarshal.list:10) */
+/* VOID:OBJECT,BOXED (gstmarshal.list:11) */
+void
+gst_marshal_VOID__OBJECT_BOXED (GClosure     *closure,
+                                GValue       *return_value,
+                                guint         n_param_values,
+                                const GValue *param_values,
+                                gpointer      invocation_hint,
+                                gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__OBJECT_BOXED) (gpointer     data1,
+                                                   gpointer     arg_1,
+                                                   gpointer     arg_2,
+                                                   gpointer     data2);
+  register GMarshalFunc_VOID__OBJECT_BOXED callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__OBJECT_BOXED) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_object (param_values + 1),
+            g_marshal_value_peek_boxed (param_values + 2),
+            data2);
+}
+
+/* VOID:OBJECT,POINTER,STRING (gstmarshal.list:12) */
 void
 gst_marshal_VOID__OBJECT_POINTER_STRING (GClosure     *closure,
                                          GValue       *return_value,
@@ -212,7 +251,7 @@ gst_marshal_VOID__OBJECT_POINTER_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,STRING (gstmarshal.list:11) */
+/* VOID:OBJECT,STRING (gstmarshal.list:13) */
 void
 gst_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                  GValue       *return_value,
@@ -249,7 +288,7 @@ gst_marshal_VOID__OBJECT_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:INT,INT (gstmarshal.list:12) */
+/* VOID:INT,INT (gstmarshal.list:14) */
 void
 gst_marshal_VOID__INT_INT (GClosure     *closure,
                            GValue       *return_value,
@@ -286,7 +325,7 @@ gst_marshal_VOID__INT_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:INT64 (gstmarshal.list:13) */
+/* VOID:INT64 (gstmarshal.list:15) */
 void
 gst_marshal_VOID__INT64 (GClosure     *closure,
                          GValue       *return_value,
@@ -321,7 +360,7 @@ gst_marshal_VOID__INT64 (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT,BOXED (gstmarshal.list:14) */
+/* VOID:UINT,BOXED (gstmarshal.list:16) */
 void
 gst_marshal_VOID__UINT_BOXED (GClosure     *closure,
                               GValue       *return_value,
@@ -358,9 +397,9 @@ gst_marshal_VOID__UINT_BOXED (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT,POINTER (gstmarshal.list:15) */
+/* VOID:UINT,POINTER (gstmarshal.list:17) */
 
-/* BOOLEAN:VOID (gstmarshal.list:16) */
+/* BOOLEAN:VOID (gstmarshal.list:18) */
 void
 gst_marshal_BOOLEAN__VOID (GClosure     *closure,
                            GValue       *return_value,
@@ -397,7 +436,7 @@ gst_marshal_BOOLEAN__VOID (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:POINTER (gstmarshal.list:17) */
+/* BOOLEAN:POINTER (gstmarshal.list:19) */
 void
 gst_marshal_BOOLEAN__POINTER (GClosure     *closure,
                               GValue       *return_value,
@@ -436,7 +475,7 @@ gst_marshal_BOOLEAN__POINTER (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* POINTER:POINTER (gstmarshal.list:18) */
+/* POINTER:POINTER (gstmarshal.list:20) */
 void
 gst_marshal_POINTER__POINTER (GClosure     *closure,
                               GValue       *return_value,
@@ -475,3 +514,42 @@ gst_marshal_POINTER__POINTER (GClosure     *closure,
   g_value_set_pointer (return_value, v_return);
 }
 
+/* BOXED:BOXED (gstmarshal.list:21) */
+void
+gst_marshal_BOXED__BOXED (GClosure     *closure,
+                          GValue       *return_value,
+                          guint         n_param_values,
+                          const GValue *param_values,
+                          gpointer      invocation_hint,
+                          gpointer      marshal_data)
+{
+  typedef gpointer (*GMarshalFunc_BOXED__BOXED) (gpointer     data1,
+                                                 gpointer     arg_1,
+                                                 gpointer     data2);
+  register GMarshalFunc_BOXED__BOXED callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+  gpointer v_return;
+
+  g_return_if_fail (return_value != NULL);
+  g_return_if_fail (n_param_values == 2);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_BOXED__BOXED) (marshal_data ? marshal_data : cc->callback);
+
+  v_return = callback (data1,
+                       g_marshal_value_peek_boxed (param_values + 1),
+                       data2);
+
+  g_value_take_boxed (return_value, v_return);
+}
+
