@@ -61,11 +61,10 @@ struct _GstPluginDesc {
   GstPluginExitFunc plugin_exit;	/* pointer to exiting function */
   gchar *version;			/* version of the plugin */
   gchar *license;			/* effective license of plugin */
-  gchar *copyright;			/* informal copyright notice */
   gchar *package;			/* package plugin belongs to */
   gchar *origin;			/* URL to provider of plugin */
   
-  GST_STRUCT_PADDING
+  gpointer _gst_reserved[GST_PADDING];
 };
 
 struct _GstPlugin {
@@ -78,11 +77,10 @@ struct _GstPlugin {
   gpointer 	manager;		/* managing registry */
   GModule *	module;			/* contains the module if the plugin is loaded */
 
-  GST_STRUCT_PADDING
+  gpointer _gst_reserved[GST_PADDING];
 };
 
-#ifndef GST_PLUGIN_STATIC				
-#define GST_PLUGIN_DEFINE_DYNAMIC(major,minor,name,description,init,version,license,copyright,package,origin)	\
+#define GST_PLUGIN_DEFINE(major,minor,name,description,init,version,license,package,origin)	\
 GstPluginDesc gst_plugin_desc = {		      	\
   major,						\
   minor,						\
@@ -92,15 +90,12 @@ GstPluginDesc gst_plugin_desc = {		      	\
   NULL,							\
   version,						\
   license,					      	\
-  copyright,						\
   package,						\
   origin,						\
-  GST_STRUCT_PADDING_INIT				\
-};							
-#define GST_PLUGIN_DEFINE_STATIC(major,minor,name,description,init,version,license,copyright,package,origin)
-#else
-#define GST_PLUGIN_DEFINE_DYNAMIC(major,minor,name,description,init,version,license,copyright,package,origin)
-#define GST_PLUGIN_DEFINE_STATIC(major,minor,name,description,init,version,license,copyright,package,origin)  \
+  GST_PADDING_INIT				        \
+};
+
+#define GST_PLUGIN_DEFINE_STATIC(major,minor,name,description,init,version,license,package,origin)  \
 static void GST_GNUC_CONSTRUCTOR			\
 _gst_plugin_static_init__ ##init (void)			\
 {							\
@@ -113,19 +108,13 @@ _gst_plugin_static_init__ ##init (void)			\
     NULL,					      	\
     version,						\
     license,					      	\
-    copyright,						\
     package,						\
     origin,						\
-    GST_STRUCT_PADDING_INIT				\
+    GST_PADDING_INIT				        \
   };							\
   _gst_plugin_register_static (&plugin_desc_);		\
 }			
-#endif
 
-#define GST_PLUGIN_DEFINE(major,minor,name,description,init,version,license,copyright,package,origin)\
-  GST_PLUGIN_DEFINE_STATIC(major,minor,name,description,init,version,license,copyright,package,origin)\
-  GST_PLUGIN_DEFINE_DYNAMIC(major,minor,name,description,init,version,license,copyright,package,origin)
-  
 #define GST_LICENSE_UNKNOWN "unknown"
 
 
@@ -139,11 +128,9 @@ void			_gst_plugin_initialize		(void);
 void 			_gst_plugin_register_static 	(GstPluginDesc *desc);
 
 G_CONST_RETURN gchar*	gst_plugin_get_name		(GstPlugin *plugin);
-void			gst_plugin_set_name		(GstPlugin *plugin, const gchar *name);
-G_CONST_RETURN gchar*	gst_plugin_get_longname		(GstPlugin *plugin);
+G_CONST_RETURN gchar*	gst_plugin_get_description	(GstPlugin *plugin);
 G_CONST_RETURN gchar*	gst_plugin_get_filename		(GstPlugin *plugin);
 G_CONST_RETURN gchar*	gst_plugin_get_license		(GstPlugin *plugin);
-G_CONST_RETURN gchar*	gst_plugin_get_copyright      	(GstPlugin *plugin);
 G_CONST_RETURN gchar*	gst_plugin_get_package		(GstPlugin *plugin);
 G_CONST_RETURN gchar*	gst_plugin_get_origin      	(GstPlugin *plugin);
 GModule *		gst_plugin_get_module		(GstPlugin *plugin);
